Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(569)

Unified Diff: net/http/http_network_transaction_unittest.cc

Issue 699123002: Remove HttpStreamBase. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_network_transaction_unittest.cc
diff --git a/net/http/http_network_transaction_unittest.cc b/net/http/http_network_transaction_unittest.cc
index be94493558b4b68e045781d923632249df4c4c27..661c3f4d1fc4350d06792aca60f80c87970de319 100644
--- a/net/http/http_network_transaction_unittest.cc
+++ b/net/http/http_network_transaction_unittest.cc
@@ -12193,8 +12193,8 @@ TEST_P(HttpNetworkTransactionTest, GetFullRequestHeadersIncludesExtraHeader) {
namespace {
-// Fake HttpStreamBase that simply records calls to SetPriority().
-class FakeStream : public HttpStreamBase,
+// Fake HttpStream that simply records calls to SetPriority().
+class FakeStream : public HttpStream,
public base::SupportsWeakPtr<FakeStream> {
public:
explicit FakeStream(RequestPriority priority) : priority_(priority) {}
@@ -12274,6 +12274,10 @@ class FakeStream : public HttpStreamBase,
void SetPriority(RequestPriority priority) override { priority_ = priority; }
+ UploadProgress GetUploadProgress() const override { return UploadProgress(); }
+
+ HttpStream* RenewStreamForAuth() override { return nullptr; }
tyoshino-do-not-use 2014/11/05 02:51:44 do the same for this file. NULL -> nullptr
yhirano 2014/11/05 03:55:37 Because this file is too big and contains too many
+
private:
RequestPriority priority_;

Powered by Google App Engine
This is Rietveld 408576698